@@ -13,12 +13,6 @@ pub struct Stream<T> {
     io: T,
 }
 
-impl<T> Stream<T> {
-    pub fn get_ref(&self) -> &T {
-        &self.io
-    }
-}
-
 impl<T: AsRawFd> Stream<T> {
     pub fn new(io: T) -> Stream<T> {
         Stream {
@@ -27,12 +21,15 @@ impl<T: AsRawFd> Stream<T> {
                 read_pos: 0,
                 rd: ProvidedBuf::default(),
                 read: Read::Idle,
-                wr: Vec::with_capacity(DEFAULT_BUFFER_SIZE),
                 write: Write::Idle,
             },
         }
     }
 
+    pub fn get_ref(&self) -> &T {
+        &self.io
+    }
+
     pub fn poll_read(&mut self, cx: &mut Context, buf: &mut [u8]) -> Poll<io::Result<usize>> {
         let src = ready!(self.inner.poll_fill_buf(cx, self.io.as_raw_fd()))?;
         let n = buf.len().min(src.len());
@@ -58,7 +55,6 @@ struct Inner {
     rd: ProvidedBuf,
     read_pos: usize,
     read: Read,
-    wr: Vec<u8>,
     write: Write,
 }
 
@@ -77,16 +73,12 @@ impl Inner {
         loop {
             match &mut self.write {
                 Write::Idle => {
-                    let size = buf.len().min(self.wr.capacity());
-                    self.wr.extend_from_slice(&buf[..size]);
-
-                    let action = Action::write(fd, &self.wr[..size])?;
+                    let action = Action::write(fd, buf)?;
                     self.write = Write::Writing(action);
                 }
                 Write::Writing(action) => {
                     let n = ready!(Pin::new(action).poll_write(cx))?;
                     self.write = Write::Idle;
-                    self.wr.clear();
                     return Poll::Ready(Ok(n));
                 }
             }
